==> wlp-webProfile8-20.0.0.8.zip: OSGI-INF/welcome/nls/fr/messages.js <==
var messages = {
    WELCOME: "Bienvenue dans Liberty",
    WEBSPHERE_LIBERTY_LOGO: "Logo WebSphere Liberty",
    WELCOME_SECTION: "Section Bienvenue",
    WELCOME_SECTION_CONTENT: "Contenu de la section Bienvenue",
    WEBSPHERE_APPSERVER: "WebSphere Application Server Bêta",
    HOW_TO_SETUP_ADMIN_CENTER: "Configuration du centre d'administration",
    OPEN_ADMIN_CENTER: "Ouvrir le centre d'administration",
    ADDITIONAL_RESOURCES: "Ressources complémentaires",
    EXTERNAL_RESOURCES: "Ressources externes",
    WASDEV: "Communauté WASdev",
    LIBERTY_DOC: "Documentation Liberty",
    WASDEV_FORUM: "Forum WASdev",
    HEADER_UPDATE_AVAILABLE: "Mise à jour disponible :",
    HEADER_DOWNLOAD_LINK: "Cliquez pour télécharger {0}", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Mise à jour disponible. Cliquez pour télécharger {0}", // Product name
    COPYRIGHT: "Copyright",
    IBM_LOGO: "Logo IBM",
    IBM_LICENSED: "Eléments sous licence - Propriété d'IBM © Copyright IBM Corp. 1997, 2019. All Rights Reserved. IBM et le logo IBM sont des marques d'International Business Machines Corp. dans de nombreux pays. Les autres noms de produits et de services peuvent être des marques d'IBM ou d'autres sociétés. La liste actualisée de toutes les marques d'IBM est disponible sur la page Web {0} ", // COPYRIGHT_URL
    COPYRIGHT_URL: "Copyright and trademark information.",
    CONTEXT_ROOT_NOT_FOUND: "Racine de contexte introuvable",
    UPDATE_BANNER_CLOSE_BUTTON: "Fermer la bannière",
    UPDATE_BANNER_SECTION: "Section Mise à jour de la bannière",
    UPDATE_BANNER_SECTION_CONTENT: "Contenu de la section Mise à jour de la bannière",
    BUILT_ON: "Généré le ",
    LINKS: "Liens : "
};

==> wlp-webProfile8-25.0.0.12.zip: OSGI-INF/welcome/nls/fr/messages.js <==
var messages = {
    WELCOME: "Bienvenue dans Liberty",
    WEBSPHERE_LIBERTY_LOGO: "Logo WebSphere Liberty",
    OPEN_LIBERTY_LOGO: "Logo Open Liberty ",
    WELCOME_SECTION: "Section Bienvenue",
    WELCOME_SECTION_CONTENT: "Contenu de la section Bienvenue",
    WEBSPHERE_APPSERVER: "WebSphere Application Server Bêta",
    HOW_TO_SETUP_ADMIN_CENTER: "Configuration du centre d'administration",
    OPEN_ADMIN_CENTER: "Ouvrir le centre d'administration",
    ADDITIONAL_RESOURCES: "Ressources complémentaires",
    EXTERNAL_RESOURCES: "Ressources externes",
    OPEN_LIBERT_SUPPORT: "Communauté Open Liberty ",
    WEBSPHERE_LIBERTY_DOC: "Documentation de WebSphere Liberty ",
    APPLICABLE_CONTENT: "L'intégralité du contenu relatif à Open Liberty est applicable à WebSphere Liberty : ",
    OPEN_LIBERTY_DOC: "Documentation d'Open Liberty ",
    OPEN_LIBERTY_GUIDES: "Guides d'Open Liberty ",
    WEBSPHERE_LIBERTY_FORUM: "Forum de WebSphere Liberty ",
    HEADER_UPDATE_AVAILABLE: "Mise à jour disponible : ",
    HEADER_DOWNLOAD_LINK: "Cliquez pour télécharger {0}", // Product name
    HEADER_UPDATE_AVAILABLE_DOWNLOAD_LINK: "Mise à jour disponible. Cliquez pour télécharger {0}", // Product name
    COPYRIGHT: "Copyright",
    IBM_LOGO: "Logo IBM",
    IBM_LICENSED: "Eléments sous licence - Propriété d'IBM © Copyright IBM Corp. 1997, 2019. All Rights Reserved. IBM et le logo IBM sont des marques d'International Business Machines Corp. dans de nombreux pays. Les autres noms de produits et de services peuvent être des marques d'IBM ou d'autres sociétés. La liste actualisée de toutes les marques d'IBM est disponible sur la page Web {0} ", // COPYRIGHT_URL
    COPYRIGHT_URL: "Copyright and trademark information.",
    CONTEXT_ROOT_NOT_FOUND: "Racine de contexte introuvable",
    UPDATE_BANNER_CLOSE_BUTTON: "Fermer la bannière",
    UPDATE_BANNER_SECTION: "Section Mise à jour de la bannière",
    UPDATE_BANNER_SECTION_CONTENT: "Contenu de la section Mise à jour de la bannière",
    BUILT_ON: "Généré le ",
    LINKS: "Liens : "
};
